import requests
import os
import sys


def eprint(*args, **kwargs):
    print(*args, file=sys.stderr, **kwargs)


def __post_body(tag_name: str, desc: str):
    return {
        "name": tag_name,
        "tag_name": tag_name,
        "description": desc
    }


def create_release(reader):
    desc = reader.read()

    gitlab_token = os.getenv('GITLAB_TOKEN')
    if gitlab_token is None:
        eprint('Missing GITLAB_TOKEN environment variable')
        exit(127)

    tag = os.getenv('CI_COMMIT_TAG')
    if tag is None:
        eprint('Missing CI_COMMIT_TAG environment variable. Must be run for tag')
        exit(127)

    headers = {'PRIVATE-TOKEN': gitlab_token}
    project_no = os.getenv('CI_PROJECT_ID')

    res = requests.post(f"https://gitlab.com/api/v4/projects/{project_no}/releases", headers=headers,
                        json=__post_body(tag, desc))
    if res.status_code >= 400:
        exit(1)


if __name__ == '__main__':
    create_release()



from distutils.core import setup
setup(
  name = 'miquido_gitlab_releaser',         # How you named your package folder (MyLib)
  packages = ['miquido_gitlab_releaser'],   # Chose the same as "name"
  version = '1.0.0',
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Create gitlab release from current git tag',   # Give a short description about your library
  author = 'Marek',                   # Type in your name
  author_email = 'marek.moscichowski@miquido.com',      # Type in your E-Mail
  keywords = ['GITLAB'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'requests'
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',  # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)
